==> mcg_extension-1.0.0.tar.gz: lib/extensions/datetimeextension.dart <==
extension DateWeekExtensions on DateTime {
  /// The ISO 8601 week of year [1..53].
  ///
  /// Algorithm from https://en.wikipedia.org/wiki/ISO_week_date#Algorithms
  int get weekOfYear {
    // Add 3 to always compare with January 4th, which is always in week 1
    // Add 7 to index weeks starting with 1 instead of 0
    final woy = ((ordinalDate - weekday + 10) ~/ 7);

    // If the week number equals zero, it means that the given date belongs to the preceding (week-based) year.
    if (woy == 0) {
      // The 28th of December is always in the last week of the year
      return DateTime(year - 1, 12, 28).weekOfYear;
    }

    // If the week number equals 53, one must check that the date is not actually in week 1 of the following year
    if (woy == 53 && DateTime(year, 1, 1).weekday != DateTime.thursday && DateTime(year, 12, 31).weekday != DateTime.thursday) {
      return 1;
    }

    return woy;
  }

  /// The ordinal date, the number of days since December 31st the previous year.
  ///
  /// January 1st has the ordinal date 1
  ///
  /// December 31st has the ordinal date 365, or 366 in leap years
  int get ordinalDate {
    const offsets = [0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334];
    return offsets[month - 1] + day + (isLeapYear && month > 2 ? 1 : 0);
  }

  /// True if this date is on a leap year.
  bool get isLeapYear {
    return year % 4 == 0 && (year % 100 != 0 || year % 400 == 0);
  }
}

class DateFormatType {
  static const String d_MMM_HH_mm = "d-MMM, HH:mm";
  static const String d_MMM_yy = "d-MMM-yy";
  static const String d_MMM_yyyy = "d-MMM-yyyy";
  static const String d_MMMM_yyyy = "d-MMMM-yyyy";
  static const String MMM = "MMM";
  static const String MMMM = "MMMM";

  ///Monday Mon
  static const String EEE = "EEE";

  ///Monday
  static const String EEEE = "EEEE";
}

==> mcg_extension-1.0.1.tar.gz: lib/extensions/datetimeextension.dart <==
import 'package:intl/intl.dart';

extension DateWeekExtensions on DateTime {
  ///"d-MMM, HH:mm"
  String dateFormat([String? format]) => DateFormat(format ?? DF.d_MMM_yyyy).format(this);

  ///Bazen gune gore key gerekiyor. 1-ara-2022 deki servis islemleri gibi
  ///ama 1-ara-2022 gibi key yaparsak arap harflerinde falan patlayabilir
  ///bu fonksiyon 1970 den beri kac gun gectigine gore gun verir.

  int get daysSinceEpoch => difference(DateTime(1970, 1, 1)).inDays;

  /// The ISO 8601 week of year [1..53].
  ///
  /// Algorithm from https://en.wikipedia.org/wiki/ISO_week_date#Algorithms
  int get weekOfYear {
    // Add 3 to always compare with January 4th, which is always in week 1
    // Add 7 to index weeks starting with 1 instead of 0
    final woy = ((ordinalDate - weekday + 10) ~/ 7);

    // If the week number equals zero, it means that the given date belongs to the preceding (week-based) year.
    if (woy == 0) {
      // The 28th of December is always in the last week of the year
      return DateTime(year - 1, 12, 28).weekOfYear;
    }

    // If the week number equals 53, one must check that the date is not actually in week 1 of the following year
    if (woy == 53 && DateTime(year, 1, 1).weekday != DateTime.thursday && DateTime(year, 12, 31).weekday != DateTime.thursday) {
      return 1;
    }

    return woy;
  }

  /// The ordinal date, the number of days since December 31st the previous year.
  ///
  /// January 1st has the ordinal date 1
  ///
  /// December 31st has the ordinal date 365, or 366 in leap years
  int get ordinalDate {
    const offsets = [0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334];
    return offsets[month - 1] + day + (isLeapYear && month > 2 ? 1 : 0);
  }

  /// True if this date is on a leap year.
  bool get isLeapYear {
    return year % 4 == 0 && (year % 100 != 0 || year % 400 == 0);
  }
}

class DF {
  DF._();
  static const String d_MMM_HH_mm = 'd-MMM, HH:mm';
  static const String d_MM_yyyy = 'd-MM-yyyy';
  static const String d_MMM_yyyy = 'd-MMM-yyyy';

  static const String d_MMM_yy = "d-MMM-yy";
  static const String d_MMMM_yyyy = "d-MMMM-yyyy";
  static const String MMM = "MMM";
  static const String MMMM = "MMMM";

  ///Monday Mon
  static const String EEE = "EEE";

  ///Monday
  static const String EEEE = "EEEE";
}
